pub struct AccountConstraints {
pub key: Pubkey,
pub program_id: Pubkey,
pub data_hash: Hash,
}Expand description
The account constraints a Condition would wait on. Note: ideally this would be function that accepts an Account and returns a bool, but we don’t have a way to pass functions over the wire. To simulate higher order programming, create your own program that includes an instruction that sets account data to a boolean. Pass that account key and program_id here.
Fields
key: PubkeyThe account holder.
program_id: PubkeyThe program id that must own the account at key.
data_hash: HashThe hash of the data in the account at key.